#####
Image
#####

.. currentmodule:: torchio.data


:class:`ScalarImage`
--------------------

.. autoclass:: ScalarImage
    :show-inheritance:


:class:`LabelMap`
-----------------

.. autoclass:: LabelMap
    :show-inheritance:


:class:`Image`
--------------

.. autoclass:: Image
    :members:
    :show-inheritance:
